use database {database};
use schema {schema};
use warehouse {warehouse};

{drop_command}

drop streamlit "{name}";
